WizardRunner class

Constructors

WizardRunner(AppModel app, MemberModel member, {required Map<String, NewAppWizardParameters> newAppWizardParameters, required bool autoPrivileged1, required String? styleFamily, required String? styleName, required AccessBloc accessBloc})

Properties

accessBloc → AccessBloc
final
app → AppModel
final
appId ↔ String
getter/setter pair
autoPrivileged1 → bool
final
hashCode → int
The hash code for this object.
no setterinherited
member → MemberModel
final
memberId ↔ String
getter/setter pair
newAppWizardParameters → Map<String, NewAppWizardParameters>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleFamily → String?
final
styleName → String?
final
uniqueId → String
final

Methods

create(AccessBloc accessBloc, WizardBloc wizardBloc) → Future<void>
getMenuItemsFor(MenuType type) → List<MenuItemModel>
getPageID(String pageType) → String?
getPublicMediumModel(AppModel app, String publicMediumModelType) → PublicMediumModel?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited