WithMenu class

Implementers

Constructors

WithMenu(AppModel app, {required String identifier, required String name})

Properties

app → AppModel
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateMenuItems(List<MenuItemModel> items) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited